@@ -104,9 +104,12 @@ private:
     };
 
 private Q_SLOTS:
-    void init()
+    void cleanupTestCase()
     {
-        QDir().rmdir(QFINDTESTDATA("fixtures/overrides/"));
+        // Be extra careful with deleting. An empty string would lead to deleting the working directory.
+        const QString overridesDirectory = QFINDTESTDATA("fixtures/overrides/");
+        QVERIFY(!overridesDirectory.isEmpty());
+        QDir(overridesDirectory).removeRecursively();
     }
 
     void testCompareFlatpakConfigsEqual()
@@ -376,9 +379,7 @@ private Q_SLOTS:
             QFINDTESTDATA(QStringLiteral("fixtures/overrides.in/com.example.cascade.user-app")),
         };
         FlatpakPermissionModel model;
-        FlatpakReferencesModel referencesModel;
-        FlatpakReference
-            reference(&referencesModel, "com.example.cascade.metadata", "x86_64", "stable", "1.0.0", "com.example.cascade.metadata", QUrl(), overrideFiles);
+        FlatpakReference reference("com.example.cascade.metadata", "x86_64", "stable", "1.0.0", "com.example.cascade.metadata", overrideFiles);
         model.setReference(&reference);
         model.setShowAdvanced(true);
         model.load();
@@ -431,15 +432,7 @@ private Q_SLOTS:
     {
         // The primary motivation behind this test is to make sure that translations aren't being pulled in for the raw names.
         FlatpakPermissionModel model;
-        FlatpakReferencesModel referencesModel;
-        FlatpakReference reference(&referencesModel,
-                                   "com.discordapp.Discord",
-                                   "x86_64",
-                                   "stable",
-                                   "0.0.24",
-                                   "Discord",
-                                   QUrl(),
-                                   mockMetadataAndOverridesFiles("com.discordapp.Discord"));
+        FlatpakReference reference("com.discordapp.Discord", "x86_64", "stable", "0.0.24", "Discord", mockMetadataAndOverridesFiles("com.discordapp.Discord"));
         model.setReference(&reference);
         model.load();
         bool containsNetwork = false;
@@ -470,14 +463,11 @@ private Q_SLOTS:
         // Test that values that are for some reason enabled and present in
         // both defaults and overrides are parsed correctly.
         FlatpakPermissionModel model;
-        FlatpakReferencesModel referencesModel;
-        FlatpakReference reference(&referencesModel,
-                                   "com.example.same.override",
+        FlatpakReference reference("com.example.same.override",
                                    "x86_64",
                                    "stable",
                                    "0.0.24",
                                    "Test Same Simple Override",
-                                   QUrl(),
                                    mockMetadataAndOverridesFiles("com.example.same.override"));
         model.setReference(&reference);
         model.setShowAdvanced(true);
@@ -527,15 +517,7 @@ private Q_SLOTS:
         // the well-known "host-etc" filesystem would not be the last one. But we want to test for the last
         // default index too.
         FlatpakPermissionModel model;
-        FlatpakReferencesModel referencesModel;
-        FlatpakReference reference(&referencesModel, //
-                                   "org.gnome.dfeet",
-                                   "x86_64",
-                                   "stable",
-                                   "0.3.16",
-                                   "D-Feet",
-                                   QUrl(),
-                                   mockMetadataAndOverridesFiles("org.gnome.dfeet"));
+        FlatpakReference reference("org.gnome.dfeet", "x86_64", "stable", "0.3.16", "D-Feet", mockMetadataAndOverridesFiles("org.gnome.dfeet"));
         model.setReference(&reference);
         model.load();
         QStringList filesystems;
@@ -566,15 +548,7 @@ private Q_SLOTS:
         // from, and saved.
         const auto metadataAndOverridesFiles = mockMetadataAndOverridesFiles("org.gnome.dfeet");
         FlatpakPermissionModel model;
-        FlatpakReferencesModel referencesModel;
-        FlatpakReference reference(&referencesModel, //
-                                   "org.gnome.dfeet",
-                                   "x86_64",
-                                   "stable",
-                                   "0.3.16",
-                                   "D-Feet",
-                                   QUrl(),
-                                   metadataAndOverridesFiles);
+        FlatpakReference reference("org.gnome.dfeet", "x86_64", "stable", "0.3.16", "D-Feet", metadataAndOverridesFiles);
         model.setReference(&reference);
         model.load();
         model.setShowAdvanced(true);
@@ -684,15 +658,7 @@ private Q_SLOTS:
     void testDBusBrokenPolicies()
     {
         FlatpakPermissionModel model;
-        FlatpakReferencesModel referencesModel;
-        FlatpakReference reference(&referencesModel, //
-                                   "org.gnome.Boxes",
-                                   "x86_64",
-                                   "stable",
-                                   "43.1",
-                                   "Boxes",
-                                   QUrl(),
-                                   mockMetadataAndOverridesFiles("org.gnome.Boxes"));
+        FlatpakReference reference("org.gnome.Boxes", "x86_64", "stable", "43.1", "Boxes", mockMetadataAndOverridesFiles("org.gnome.Boxes"));
         model.setReference(&reference);
         model.load();
         model.setShowAdvanced(true);
@@ -748,15 +714,7 @@ private Q_SLOTS:
         // Ensure override files mutate properly
         const auto metadataAndOverridesFiles = mockMetadataAndOverridesFiles("com.discordapp.Discord");
         FlatpakPermissionModel model;
-        FlatpakReferencesModel referencesModel;
-        FlatpakReference reference(&referencesModel, //
-                                   "com.discordapp.Discord",
-                                   "x86_64",
-                                   "stable",
-                                   "0.0.24",
-                                   "Discord",
-                                   QUrl(),
-                                   metadataAndOverridesFiles);
+        FlatpakReference reference("com.discordapp.Discord", "x86_64", "stable", "0.0.24", "Discord", metadataAndOverridesFiles);
         model.setReference(&reference);
         model.load();
         model.setShowAdvanced(true);
@@ -885,15 +843,7 @@ private Q_SLOTS:
     {
         const auto metadataAndOverridesFiles = mockMetadataAndOverridesFiles("com.example.unparsable.filesystems");
         FlatpakPermissionModel model;
-        FlatpakReferencesModel referencesModel;
-        FlatpakReference reference(&referencesModel,
-                                   "com.example.unparsable.filesystems",
-                                   "x86_64",
-                                   "stable",
-                                   "0.0.24",
-                                   "Unparsable Filesystems",
-                                   QUrl(),
-                                   metadataAndOverridesFiles);
+        FlatpakReference reference("com.example.unparsable.filesystems", "x86_64", "stable", "0.0.24", "Unparsable Filesystems", metadataAndOverridesFiles);
         model.setReference(&reference);
         model.load();
         model.setShowAdvanced(true);
@@ -911,14 +861,11 @@ private Q_SLOTS:
 
     void testDefaultHomeFilesystem()
     {
-        FlatpakReferencesModel referencesModel;
-        FlatpakReference reference(&referencesModel,
-                                   "com.example.home.filesystems",
+        FlatpakReference reference("com.example.home.filesystems",
                                    "x86_64",
                                    "stable",
                                    "0.0.24",
                                    "Default Home Filesystems",
-                                   QUrl(),
                                    mockMetadataAndOverridesFiles("com.example.home.filesystems"));
         FlatpakPermissionModel model;
         model.setReference(&reference);
@@ -951,14 +898,11 @@ private Q_SLOTS:
     void testValidNames()
     {
         FlatpakPermissionModel model;
-        FlatpakReferencesModel referencesModel;
-        FlatpakReference reference(&referencesModel,
-                                   "com.example.valid.names",
+        FlatpakReference reference("com.example.valid.names",
                                    "x86_64",
                                    "stable",
                                    "1.0",
                                    "Valid Names",
-                                   QUrl(),
                                    mockMetadataAndOverridesFiles("com.example.valid.names"));
         model.setReference(&reference);
         model.load();
